@@ -3,21 +3,24 @@
 ## for glm.
 
 ## Variables affecting the sampling process but not the posterior distribution.
-ergmm.control<-function(sample.size=4000,
+ergmm.control<-control.ergmm<-function(sample.size=4000,
                         burnin=10000,
                         interval=10,
                         threads=1,
+                        kl.threads=1,
                         mle.maxit=100,
                         Z.delta=0.6,
+                        RE.delta=0.6,
                         group.deltas=0.4,
                         pilot.runs=4,
                         pilot.factor=0.8,
                         pilot.discard.first=0.5,
                         target.acc.rate=0.234,
                         backoff.threshold=0.05,
-                        backoff.factor=0.1,
+                        backoff.factor=0.2,
                         accept.all=FALSE,
-                        store.burnin=FALSE){
+                        store.burnin=FALSE,
+                        refine.user.start=TRUE){
   control<-list()
   for(arg in names(formals(sys.function())))
     control[[arg]]<-get(arg)
@@ -26,7 +29,7 @@ ergmm.control<-function(sample.size=4000,
 
 ergmm.prior<-function(...,adjust.beta.var=TRUE){
   prior<-list(...)
-  prior$adjust.beta.var<-adjust.beta.var
+  prior[["adjust.beta.var"]]<-adjust.beta.var
   as.ergmm.par.list(prior)
 }
 
